# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

fun5 <- function(yy_g) {
    .Call('_NanoStringDiff_fun5', PACKAGE = 'NanoStringDiff', yy_g)
}

